Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

T |
| text, Title
| textAlign, Title
| textColor $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.CanvasAxisTickRenderer Legend Title
| themes, $.jqplot.ThemeEngine
| thickness, $.jqplot.DonutRenderer
| tickColor, $.jqplot.MeterGaugeRenderer
| tickInset $.jqplot.DateAxisRenderer$.jqplot.LinearAxisRenderer
| tickInterval, Axis
| tickLength, $.jqplot.OHLCRenderer
| tickMode, $.jqplot.MekkoAxisRenderer
| tickOptions, Axis
| tickPadding, $.jqplot.MeterGaugeRenderer
| tickRenderer $.jqplot.CategoryAxisRenderer$.jqplot.DateAxisRenderer Axis
| ticks $.jqplot.MeterGaugeRenderer Axis
| tickSpacing $.jqplot.MeterGaugeRenderer Axis
| title, jqPlot
| Title
| tooltipAxes, $.jqplot.Highlighter
| tooltipAxisGroups, $.jqplot.Cursor
| tooltipFadeSpeed $.jqplot.CanvasOverlay$.jqplot.Highlighter
| tooltipFormatString $.jqplot.CanvasOverlay$.jqplot.Cursor$.jqplot.Highlighter
| tooltipLocation $.jqplot.CanvasOverlay$.jqplot.Cursor$.jqplot.Highlighter
| tooltipOffset $.jqplot.CanvasOverlay$.jqplot.Cursor$.jqplot.Highlighter
| transposedData, $.jqplot.BarRenderer
| type, $.jqplot.Trendline
U |
| upBodyColor, $.jqplot.OHLCRenderer
| Usage
| useAxesFormatters $.jqplot.Cursor$.jqplot.Highlighter
| useNegativeColors, Series
| useSeriesColor, Axis
V |
| varyBarColor, $.jqplot.BarRenderer
| varyBlockColors, $.jqplot.BlockRenderer
| varyBubbleColors, $.jqplot.BubbleRenderer
| Version
| VerticalLine
W |
| waterfall, $.jqplot.BarRenderer
| wickColor, $.jqplot.OHLCRenderer
| widthRatio, $.jqplot.FunnelRenderer
X |
| xaxis $.jqplot.CanvasOverlay Series
| xmax, HorizontalLine
| xmin, HorizontalLine
| xoffset, Legend
| xpadding, $.jqplot.PointLabels
Y |
| y, HorizontalLine
| yaxis $.jqplot.CanvasOverlay Series
| yoffset, Legend
| ypadding, $.jqplot.PointLabels
| yvalues, $.jqplot.Highlighter
Z |
| zoom, $.jqplot.Cursor
| zoomProxy, $.jqplot.Cursor.$.jqplot.Cursor

> this.text = text

text of the title;

> this.textAlign

css text-align spec for the text.

> this.textColor

css spec for the color attribute.

> this.textColor = '#666666'

css spec for the color attribute.

> this.textColor = '#666666'

css spec for the color attribute.

> this.textColor

css color spec for the legend text.

> this.textColor

css color spec for the text.

> this.themes = {}

hash of themes managed by the theme engine.

> this.thickness = null

thickness of the donut, auto computed by default Overridden by if innerDiameter is specified.

> this.tickColor = "#989898"

color of the tick marks around the gauge.

> this.tickInset = 0

Controls the amount to inset the first and last ticks from the edges of the grid, in multiples of the tick interval.

> this.tickInset = 0

Controls the amount to inset the first and last ticks from the edges of the grid, in multiples of the tick interval.

> this.tickInterval

number of units between ticks.

> this.tickLength = 'auto'

length of the line in pixels indicating open and close price.

> this.tickMode

How to space the ticks on the axis.

> this.tickOptions = {}

Options that will be passed to the tickRenderer, see $.jqplot.AxisTickRenderer options.

> this.tickPadding = null

padding of the tick marks to the outer ring and the tick labels to marks.
A class of a rendering engine for creating the ticks labels displayed on the plot, See $.jqplot.AxisTickRenderer.
A class of a rendering engine for creating the ticks labels displayed on the plot, See $.jqplot.AxisTickRenderer.

> this.tickRenderer = $.jqplot.AxisTickRenderer

A class of a rendering engine for creating the ticks labels displayed on the plot, See $.jqplot.AxisTickRenderer.

> this.ticks = []

Array of tick values.

> this.ticks = []

1D [val, val, ...] or 2D [[val, label], [val, label], ...] array of ticks for the axis.

> this.tickSpacing = 30

Degrees between ticks.

> this.tickSpacing = 75

Approximate pixel spacing between ticks on graph.

> this.title = new Title()

Title object.
Plot Title object.

> this.tooltipAxes = 'both'

Which axes to display in tooltip, ‘x’, ‘y’ or ‘both’, ‘xy’ or ‘yx’ ‘both’ and ‘xy’ are equivalent, ‘yx’ reverses order of labels.

> this.tooltipAxisGroups = []

Show position for the specified axes.
‘slow’, ‘def’, ‘fast’, or number of milliseconds.

> this.tooltipFadeSpeed = "fast"

‘slow’, ‘def’, ‘fast’, or number of milliseconds.

> tooltipFormatString: '%d, %d' }

Format string passed the x and y values of the cursor on the line.

> this.tooltipFormatString = '%.4P, %.4P'

sprintf format string for the tooltip.

> this.tooltipFormatString = '%.5P'

sprintf format string for the tooltip.
Where to position tooltip, ‘n’, ‘ne’, ‘e’, ‘se’, ‘s’, ‘sw’, ‘w’, ‘nw’

> this.tooltipLocation = 'se'

Where to position tooltip.

> this.tooltipLocation = 'nw'

Where to position tooltip, ‘n’, ‘ne’, ‘e’, ‘se’, ‘s’, ‘sw’, ‘w’, ‘nw’
Pixel offset of tooltip from the highlight.

> this.tooltipOffset = 6

Pixel offset of tooltip from the grid boudaries or cursor center.

> this.tooltipOffset = 2

Pixel offset of tooltip from the highlight.

> this.transposedData = true

NOT IMPLEMENTED YET.

> this.type = 'linear'

Either ‘exponential’, ‘exp’, or ‘linear’.

> this.upBodyColor = null

Color of candlestick body of an “up” day.
See jqPlot Usage

> this.useAxesFormatters = true

Use the x and y axes formatters to format the text in the tooltip.

> this.useAxesFormatters = true

Use the x and y axes formatters to format the text in the tooltip.

> this.useNegativeColors = true

true to color negative values differently in filled and bar charts.

> this.useSeriesColor = false

Use the color of the first series associated with this axis for the tick marks and line bordering this axis.

> this.varyBarColor = false

true to color each bar of a series separately rather than have every bar of a given series the same color.

> this.varyBlockColors = false

true to vary the color of each block in this series according to the seriesColors array.

> this.varyBubbleColors = true

True to vary the color of each bubble in this series according to the seriesColors array.
version: 1.0.7 revision: 1224
A straight vertical line.

> this.waterfall = false

true to enable waterfall plot.

> this.wickColor = null

color of the hi-lo line thorugh the candlestick body.

> this.widthRatio = 0.2

The ratio of the width of the top of the funnel to the bottom.
X axis to use for positioning/scaling the line.

> this.xaxis = 'xaxis'

which x axis to use with this series, either ‘xaxis’ or ‘x2axis’.
x value for the end of the line, null to scale to axis max.
x value for the start of the line, null to scale to axis min.

> this.xoffset = 0

DEPRECATED.

> this.xpadding = 6

horizontal padding in pixels between point and label
y value to position the line
Y axis to use for positioning/scaling the line.

> this.yaxis = 'yaxis'

which y axis to use with this series, either ‘yaxis’ or ‘y2axis’.

> this.yoffset = 0

DEPRECATED.

> this.ypadding = 6

vertical padding in pixels between point and label

> this.yvalues = 1

Number of y values to expect in the data point array.

> this.zoom = false

Enable plot zooming.

> $.jqplot.Cursor.zoomProxy = function( | targetPlot,
> | controllerPlot | )

links targetPlot to controllerPlot so that plot zooming of targetPlot will be controlled by zooming on the controllerPlot.
Close